==> spip_3.2.11.orig.tar.xz: plugins-dist/medias/lang/medias_oc_gsc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=oc_gsc
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'AJUSTAR UN DOCUMENT', # MODIF
	'bouton_ajouter_image' => 'AJUSTAR UN IMATGE', # MODIF

	// D
	'double_clic_inserer_doc' => 'Besclicatz entà inserir aquera acorcida dens lo tèxt.',

	// E
	'entree_dimensions' => 'Dimensions:',
	'entree_titre_document' => 'Títol deu document:',
	'entree_titre_image' => 'Títol de l’imatge:',

	// I
	'image_tourner_180' => 'Rotacion 180°',
	'image_tourner_droite' => 'Rotacion 90° cap a dreta',
	'image_tourner_gauche' => 'Rotacion 90° cap a esquèrra',
	'info_document' => 'Document ',
	'info_documents' => 'Documents',
	'info_inclusion_directe' => 'Inclusion dirècta:',
	'info_inclusion_vignette' => 'Inclusion de la vinheta:',
	'info_installer_tous_documents' => 'Installar tots los documents ',
	'info_logo_max_taille' => 'Los lògos qu’an de har mensh de @maxi@ (aqueste fichièr que hè @actuel@).',
	'info_portfolio' => 'Pòrtfòlio',
	'info_referencer_doc_distant' => 'Referenciar un document dens l’Internet:',
	'info_telecharger' => 'Telecargar a partir deu vòste ordenader:',

	// T
	'texte_documents_joints' => 'Que podetz autorizar que s’ajusten documents (fichièrs burotics, imatges,
 multimèdia, etc.) aus articles e/o a las rubricas. Aqueths fichièrs
 que pòden puish estar referenciats dens
 l’article, o aparéisher a despart.', # MODIF
	'texte_documents_joints_2' => 'Aqueth reglatge n’empacha pas d’inserir imatges dirèctament dens los articles.', # MODIF
	'titre_documents_joints' => 'Documents junts',
	'tout_dossier_upload' => 'Tot lo dorsièr @upload@',

	// U
	'upload_fichier_zip' => 'Fichièr ZIP',
	'upload_fichier_zip_texte' => 'Lo fichièr que prepausatz d’installar qu’ei un fichièr Zip.',
	'upload_fichier_zip_texte2' => 'Aqueth fichièr que pòt estar:',
	'upload_limit' => 'Aqueth fichièr qu’ei tròp gròs peu servider; la talha maxima autorizada en <i>upload</i> qu’ei de @max@.',
	'upload_zip_decompacter' => 'descomprimit e cada element que contien installat suu sit. Alavetz los fichièrs que seràn installats suu sit que son:',
	'upload_zip_telquel' => 'installat tau com ei, com archiu comprimit Zip;'
);

==> spip_4.4.5+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_oc_gsc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=oc_gsc
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'AJUSTAR UN DOCUMENT', # MODIF
	'bouton_ajouter_image' => 'AJUSTAR UN IMATGE', # MODIF

	// D
	'double_clic_inserer_doc' => 'Besclicatz entà inserir aquera acorcida dens lo tèxt.',

	// E
	'entree_dimensions' => 'Dimensions:',
	'entree_titre_document' => 'Títol deu document:',
	'entree_titre_image' => 'Títol de l’imatge:',

	// I
	'image_tourner_180' => 'Rotacion 180°',
	'image_tourner_droite' => 'Rotacion 90° cap a dreta',
	'image_tourner_gauche' => 'Rotacion 90° cap a esquèrra',
	'info_document' => 'Document ',
	'info_documents' => 'Documents',
	'info_inclusion_directe' => 'Inclusion dirècta:',
	'info_inclusion_vignette' => 'Inclusion de la vinheta:',
	'info_installer_tous_documents' => 'Installar tots los documents ',
	'info_logo_max_taille' => 'Los lògos qu’an de har mensh de @maxi@ (aqueste fichièr que hè @actuel@).',
	'info_portfolio' => 'Pòrtfòlio',
	'info_referencer_doc_distant' => 'Referenciar un document dens l’Internet:',
	'info_telecharger' => 'Telecargar a partir deu vòste ordenader:',

	// T
	'texte_documents_joints' => 'Que podetz autorizar que s’ajusten documents (fichièrs burotics, imatges,
 multimèdia, etc.) aus articles e/o a las rubricas. Aqueths fichièrs
 que pòden puish estar referenciats dens
 l’article, o aparéisher a despart.', # MODIF
	'texte_documents_joints_2' => 'Aqueth reglatge n’empacha pas d’inserir imatges dirèctament dens los articles.', # MODIF
	'titre_documents_joints' => 'Documents junts',
	'tout_dossier_upload' => 'Tot lo dorsièr @upload@',

	// U
	'upload_fichier_zip' => 'Fichièr ZIP',
	'upload_fichier_zip_texte' => 'Lo fichièr que prepausatz d’installar qu’ei un fichièr Zip.',
	'upload_fichier_zip_texte2' => 'Aqueth fichièr que pòt estar:',
	'upload_limit' => 'Aqueth fichièr qu’ei tròp gròs peu servider; la talha maxima autorizada en <i>upload</i> qu’ei de @max@.',
	'upload_zip_decompacter' => 'descomprimit e cada element que contien installat suu sit. Alavetz los fichièrs que seràn installats suu sit que son:',
	'upload_zip_telquel' => 'installat tau com ei, com archiu comprimit Zip;',
];
